pub struct SystemHandles {
pub root_job: Job,
pub vmex_resource: Resource,
pub power_resource: Option<Resource>,
pub vdso_vmo: Vmo,
pub zbi_vmo: Vmo,
pub log: SystemLog,
pub startup_handles: Vec<StartupHandle>,
}Expand description
Essential system handles extracted from the bootstrap capabilities message required to setup and launch the next program.
Fields
root_job: JobRoot job handle for creating child processes and default jobs.
vmex_resource: ResourceVMEX resource handle for creating executable VMOs.
power_resource: Option<Resource>Power resource handle for power off / shutdown.
vdso_vmo: VmoHandle to the stable vDSO VMO.
zbi_vmo: VmoHandle to the ZBI VMO containing boot payload.
log: SystemLogHandle to the debug log or log socket.
startup_handles: Vec<StartupHandle>Additional startup handles (resources, vDSOs, kernel files) to pass to the child process.
Implementations
Sourceimpl SystemHandles
impl SystemHandles
Sourcepub fn from_handles(
handles: impl IntoIterator<Item = HandleInfo>,
) -> Result<Self, Error>
pub fn from_handles( handles: impl IntoIterator<Item = HandleInfo>, ) -> Result<Self, Error>
Extracts essential system handles from the provided handle iterator.