[−][src]Struct program::Program
Store and expose a static, shared reference to a process name.
Fields
name: &'static strMethods
impl Program[src]
pub fn new(name: &'static str) -> Self[src]
Create a new Program that holds a static, shared reference to a program name.
pub fn perror<E: Display>(&self, e: E) -> ![src]
Print an error message to stderr and exit with an exit status of 1.